# ---------------------------------------------------------- #
# This file replicates the main analysis of the paper
# "Quantile-based Test for Heterogeneous Treatment Effects"
# by EunYi Chung and Mauricio Olivares.
#
# This scrip assumes the replicator has acquired the raw
# data and processed it using the programs provided by the
# authors. See the README for more details.
#
# ------------------------------------ #
# Author: Mauricio Olivares
# LMU Munich
# ------------------------------------ #

# Part I: Define the location of the root directory for the project

# Part I.a: Install and load the rprojroot package if it's not already installed
if (!requireNamespace("rprojroot", quietly = TRUE)) {
  install.packages("rprojroot")
}
library(rprojroot)

# Part I.b: Set the root directory of the project
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))
root <- find_root(has_file("LICENSE.txt"))

# Part I.c: Define the main directories
acquired <- file.path(root, "data", "acquired")
processed <- file.path(root, "data", "processed")
outputs <- file.path(root, "analysis")
programs <- file.path(root, "programs")


# # Part I.d: Load necessary libraries and function scripts
source(file.path(root, "programs", "global_libraries.R"))
source(file.path(root, "programs", "PT.qp.R"))
source(file.path(root, "programs", "report.pvalues.R"))


# Part II: Load the processed data from the Jobs First program.
# See README for more details.

dta_file <- file.path(root, "data", "processed", "pre-processed.dta")
dat2 <- read.dta13(dta_file, convert.underscore = TRUE, nonint.factors = TRUE)


# Part III: Data Carpentry

# We will test the null hypothesis of constant treatment effects
# across subgroups for those with positive earnings

dat1 <- dat2 %>% dplyr::filter(ernq>0)

# ----------------------------
# Codebook:
# ed:      Education
# ykid:    Age of youngest kid
# mh:      Marital Status
# pq7e:    Earnings level seventh Q pre-RA
# npqe:    Number of pre-RA Q with earnings
# wh:      Welfare receipt seventh Q pre-RA

# List of covariates we want. The order of the list is
# the order of the rows in Table 2

list.covar <- c("quarter", "ed", "ykid", "mh", "pq7e", "npqe", "wh",
                "ed.ykid", "ed.mh", "pq7e.ed", "npqe.ed", "ed.wh",
                "ykid.mh", "pq7e.ykid", "npqe.ykid", "wh.ykid",
                "pq7e.mh", "npqe.mh", "wh.mh", "pq7e.npqe", "pq7e.wh", "npqe.wh")

# ------------------------------------------------ #
# Subset for the quarters we're interested in
dat <- dat1 %>% dplyr::filter(quarter>=1 & quarter<=7) %>%select(ernq,e,all_of(list.covar))
rm(dat1,dat2,dta_file)
q <- max(dat$quarter)




# Part IV: Empirical Analysis as in the main text
# The following code replicates the main analysis of the paper
# It calculates the p-values for subgroups defined by covariate
# levels, as described in the main text.

# Parameters for the quantile process and permutation test
n.perm=999
alpha=0.05
taus <- seq(0.1,0.9,by=0.02)

# ------------------------------ #
#   All sample and by quarter    #

out.allsample <- matrix(NA,ncol = 2,nrow = q)
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = q, style = 3)
for (i in 1:q) {
  setTxtProgressBar(pb, i)
  dat.allsample.q <- data.frame(Y=dat$ernq[dat$quarter==i],X=dat$e[dat$quarter==i])
  test.results <- PT.qp(dat.allsample.q,taus,n.perm)
  out.allsample[i,1] <- test.results$`p-value`
  out.allsample[i,2] <- test.results$`NA rate`
}
close(pb)
ptm1 <- proc.time()
out.allsample <- out.allsample[order(out.allsample[,1]),]
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
p.adjust(out.allsample[,1],method = "bonferroni")
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
p.adjust(out.allsample[,1],method = "holm")
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")




# ------------------- #
#       Education     #

k <- max(dat$ed)
out.ed <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.ed <- data.frame(Y=dat$ernq[dat$ed==i&dat$quarter==j],X=dat$e[dat$ed==i&dat$quarter==j])
    test.results <- PT.qp(dat.ed,taus,n.perm)
    out.ed[i,1,j]=test.results$`p-value`
    out.ed[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.ed)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")


# ----------------------- #
#   Age of youngest kid   #

k <- max(dat$ykid)
out.ykid <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.ykid <- data.frame(Y=dat$ernq[dat$ykid==i&dat$quarter==j],X=dat$e[dat$ykid==i&dat$quarter==j])
    test.results <- PT.qp(dat.ykid,taus,n.perm)
    out.ykid[i,1,j]=test.results$`p-value`
    out.ykid[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.ykid)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")


# ----------------------- #
#      Marital Status     #

k <- max(dat$mh)
out.mh <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.mh <- data.frame(Y=dat$ernq[dat$mh==i&dat$quarter==j],X=dat$e[dat$mh==i&dat$quarter==j])
    test.results <- PT.qp(dat.mh,taus,n.perm)
    out.mh[i,1,j]=test.results$`p-value`
    out.mh[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.mh)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")


# -------------------------------- #
# Earnings level seventh Q pre-RA  #

k <- max(dat$pq7e)
out.pq7e <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.pq7e <- data.frame(Y=dat$ernq[dat$pq7e==i&dat$quarter==j],X=dat$e[dat$pq7e==i&dat$quarter==j])
    test.results <- PT.qp(dat.pq7e,taus,n.perm)
    out.pq7e[i,1,j]=test.results$`p-value`
    out.pq7e[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.pq7e)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")

# --------------------------------- #
# Number of pre-RA Q with earnings  #

k <- max(dat$npqe)
out.npqe <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.npqe <- data.frame(Y=dat$ernq[dat$npqe==i&dat$quarter==j],X=dat$e[dat$npqe==i&dat$quarter==j])
    test.results <- PT.qp(dat.npqe,taus,n.perm)
    out.npqe[i,1,j]=test.results$`p-value`
    out.npqe[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.npqe)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")



# --------------------------------- #
# Welfare receipt seventh Q pre-RA  #

k <- max(dat$wh)
out.wh <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.wh <- data.frame(Y=dat$ernq[dat$wh==i&dat$quarter==j],X=dat$e[dat$wh==i&dat$quarter==j])
    test.results <- PT.qp(dat.wh,taus,n.perm)
    out.wh[i,1,j]=test.results$`p-value`
    out.wh[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.wh)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")


# --------------------------------- #
# Education subgroups interacted 
# with age of youngest child

k <- max(dat$ed.ykid)
out.ed.ykid <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.ed.ykid <- data.frame(Y=dat$ernq[dat$ed.ykid==i&dat$quarter==j],X=dat$e[dat$ed.ykid==i&dat$quarter==j])
    test.results <- PT.qp(dat.ed.ykid,taus,n.perm)
    out.ed.ykid[i,1,j]=test.results$`p-value`
    out.ed.ykid[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.ed.ykid)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")

# --------------------------------- #
# Education subgroups interacted 
# with marital status

k <- max(dat$ed.mh)
out.ed.mh <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.ed.mh <- data.frame(Y=dat$ernq[dat$ed.mh==i&dat$quarter==j],X=dat$e[dat$ed.mh==i&dat$quarter==j])
    test.results <- PT.qp(dat.ed.mh,taus,n.perm)
    out.ed.mh[i,1,j]=test.results$`p-value`
    out.ed.mh[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.ed.mh)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")

# ------------------------------------ #
# Education subgroups interacted 
# with Earnings level seventh Q pre-RA

k <- max(dat$pq7e.ed)
out.pq7e.ed <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.pq7e.ed <- data.frame(Y=dat$ernq[dat$pq7e.ed==i&dat$quarter==j],X=dat$e[dat$pq7e.ed==i&dat$quarter==j])
    test.results <- PT.qp(dat.pq7e.ed,taus,n.perm)
    out.pq7e.ed[i,1,j]=test.results$`p-value`
    out.pq7e.ed[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.pq7e.ed)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")

# ------------------------------------- #
# Education subgroups interacted 
# with Number of pre-RA Q with earnings

k <- max(dat$npqe.ed)
out.npqe.ed <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.npqe.ed <- data.frame(Y=dat$ernq[dat$npqe.ed==i&dat$quarter==j],X=dat$e[dat$npqe.ed==i&dat$quarter==j])
    test.results <- PT.qp(dat.npqe.ed,taus,n.perm)
    out.npqe.ed[i,1,j]=test.results$`p-value`
    out.npqe.ed[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.npqe.ed)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")

# --------------------------------- #
# Education subgroups interacted 
# with Welfare receipt seventh Q pre-RA

k <- max(dat$ed.wh)
out.ed.wh <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.ed.wh <- data.frame(Y=dat$ernq[dat$ed.wh==i&dat$quarter==j],X=dat$e[dat$ed.wh==i&dat$quarter==j])
    test.results <- PT.qp(dat.ed.wh,taus,n.perm)
    out.ed.wh[i,1,j]=test.results$`p-value`
    out.ed.wh[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.ed.wh)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")

# ------------------------------------- #
# Age of youngest child interacted with
# Marital status

k <- max(dat$ykid.mh)
out.ykid.mh <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.ykid.mh <- data.frame(Y=dat$ernq[dat$ykid.mh==i&dat$quarter==j],X=dat$e[dat$ykid.mh==i&dat$quarter==j])
    test.results <- PT.qp(dat.ykid.mh,taus,n.perm)
    out.ykid.mh[i,1,j]=test.results$`p-value`
    out.ykid.mh[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.ykid.mh)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")

# -------------------------------------- #
# Age of youngest child interacted with
# Earnings level seventh Q pre-RA

k <- max(dat$pq7e.ykid)
out.pq7e.ykid <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.pq7e.ykid <- data.frame(Y=dat$ernq[dat$pq7e.ykid==i&dat$quarter==j],X=dat$e[dat$pq7e.ykid==i&dat$quarter==j])
    test.results <- PT.qp(dat.pq7e.ykid,taus,n.perm)
    out.pq7e.ykid[i,1,j]=test.results$`p-value`
    out.pq7e.ykid[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.pq7e.ykid)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")

# --------------------------------- #
# Age of youngest child interacted with
# Number of pre-RA Q with earnings

k <- max(dat$npqe.ykid)
out.npqe.ykid <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.npqe.ykid <- data.frame(Y=dat$ernq[dat$npqe.ykid==i&dat$quarter==j],X=dat$e[dat$npqe.ykid==i&dat$quarter==j])
    test.results <- PT.qp(dat.npqe.ykid,taus,n.perm)
    out.npqe.ykid[i,1,j]=test.results$`p-value`
    out.npqe.ykid[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.npqe.ykid)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")

# --------------------------------- #
# Age of youngest child interacted with
# Welfare receipt seventh Q pre-RA

k <- max(dat$wh.ykid)
out.wh.ykid <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.wh.ykid <- data.frame(Y=dat$ernq[dat$wh.ykid==i&dat$quarter==j],X=dat$e[dat$wh.ykid==i&dat$quarter==j])
    test.results <- PT.qp(dat.wh.ykid,taus,n.perm)
    out.wh.ykid[i,1,j]=test.results$`p-value`
    out.wh.ykid[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.wh.ykid)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")

# --------------------------------- #
# Marital status interacted with
# Earnings level seventh Q pre-RA

k <- max(dat$pq7e.mh)
out.pq7e.mh <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.pq7e.mh <- data.frame(Y=dat$ernq[dat$pq7e.mh==i&dat$quarter==j],X=dat$e[dat$pq7e.mh==i&dat$quarter==j])
    test.results <- PT.qp(dat.pq7e.mh,taus,n.perm)
    out.pq7e.mh[i,1,j]=test.results$`p-value`
    out.pq7e.mh[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.pq7e.mh)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")

# --------------------------------- #
# Marital status interacted with
# Number of pre-RA Q with earnings

k <- max(dat$npqe.mh)
out.npqe.mh <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.npqe.mh <- data.frame(Y=dat$ernq[dat$npqe.mh==i&dat$quarter==j],X=dat$e[dat$npqe.mh==i&dat$quarter==j])
    test.results <- PT.qp(dat.npqe.mh,taus,n.perm)
    out.npqe.mh[i,1,j]=test.results$`p-value`
    out.npqe.mh[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.npqe.mh)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")

# --------------------------------- #
# Marital status interacted with
# Welfare receipt seventh Q pre-RA

k <- max(dat$wh.mh)
out.wh.mh <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.wh.mh <- data.frame(Y=dat$ernq[dat$wh.mh==i&dat$quarter==j],X=dat$e[dat$wh.mh==i&dat$quarter==j])
    test.results <- PT.qp(dat.wh.mh,taus,n.perm)
    out.wh.mh[i,1,j]=test.results$`p-value`
    out.wh.mh[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.wh.mh)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")

# --------------------------------- #
# Earnings level seventh Q pre-RA
# subgroups interacted with
# Number of pre-RA Q with earnings

k <- max(dat$pq7e.npqe)
out.pq7e.npqe <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.pq7e.npqe <- data.frame(Y=dat$ernq[dat$pq7e.npqe==i&dat$quarter==j],X=dat$e[dat$pq7e.npqe==i&dat$quarter==j])
    test.results <- PT.qp(dat.pq7e.npqe,taus,n.perm)
    out.pq7e.npqe[i,1,j]=test.results$`p-value`
    out.pq7e.npqe[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.pq7e.npqe)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")

# --------------------------------- #
# Earnings level seventh Q pre-RA
# subgroups interacted with
# Welfare receipt seventh Q pre-RA

k <- max(dat$pq7e.wh)
out.pq7e.wh <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.pq7e.wh <- data.frame(Y=dat$ernq[dat$pq7e.wh==i&dat$quarter==j],X=dat$e[dat$pq7e.wh==i&dat$quarter==j])
    test.results <- PT.qp(dat.pq7e.wh,taus,n.perm)
    out.pq7e.wh[i,1,j]=test.results$`p-value`
    out.pq7e.wh[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.pq7e.wh)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")

# --------------------------------- #
# Number of quarters any earnings
# pre-RA subgroup interacted with
# Welfare receipt seventh Q pre-RA

k <- max(dat$npqe.wh)
out.npqe.wh <- array(NA, dim = c(k,2,q))
ptm0 <- proc.time()
pb <- txtProgressBar(min = 0, max = k+q, style = 3)
for (j in 1:q) {
  for (i in 1:k) {
    setTxtProgressBar(pb, j+i)
    dat.npqe.wh <- data.frame(Y=dat$ernq[dat$npqe.wh==i&dat$quarter==j],X=dat$e[dat$npqe.wh==i&dat$quarter==j])
    test.results <- PT.qp(dat.npqe.wh,taus,n.perm)
    out.npqe.wh[i,1,j]=test.results$`p-value`
    out.npqe.wh[i,2,j]=test.results$`NA rate`
  }
}
close(pb)
ptm1 <- proc.time()
results <- report.pvalues(out.npqe.wh)
cat("* ------------------------- *\n")
cat("Adjused P-Values (Bonferroni): ")
results$`Bonferroni p-values`
cat("* ------------------------- *\n")
cat("Adjused P-Values (Holm): ")
results$`Holm p-values`
cat(sprintf("Elapsed Time (min): %1.3f", (ptm1 - ptm0)[3]/60), "\n")



# ------------------------------- #
#      Export all the results     #
# ------------------------------- #

save.image(file="raw p-values.RData")
