# Permutation Test based on Khamaladze Transformation
# ------------------------------------ #
# Author: Mauricio Olivares
# LMU Munich
# ------------------------------------ #

PT.qp <- function(fake,taus=taus,n.perm=499){
  # ---------------
  # fake:   data frame. It contains two variables, 
  #         outcome and treatment indicator
  # taus:   sequence of quantiles. Some functions
  #         in quantreg break if the grid is not
  #         sufficiently fine.
  # n.perm: integer. Number of permutations.
  # 
  # Returns a scalar indicating the pvalue.
  # ---------------
  
  # Return objects
  object_results<-list() 
  
  # Recenter the observations
  te.mean <- mean(fake$Y[fake$X == 1])-mean(fake$Y[fake$X == 0])
  fake$Y.star <- fake$Y-fake$X*te.mean
  
  # Observed Test Statistic
  fit.mod <- tryCatch(error=function(cnd) NA, KhmaladzeTest(Y.star~X,data=fake,taus=taus));
  
  if( is.na(fit.mod$Tn) ){
    object_results$pvalue <- NA
    object_results$na.rate <- NA
  } else{
    Tn.obs <- fit.mod$Tn
    # Permute Data
    Sn  <- group.action(fake$X,n.perm,"permutations")
    # Generate a list of data frames. This step is needed because
    # KhmaladzeTest takes data frames as inputs.
    gen.data <- lapply(1:n.perm,function(s) data.frame(Y=fake$Y.star,X=Sn[,s]))
    # Recalculate the test statistic for all permutations. This forms a 
    # list. Extract all the non missing values from this list.
    recalculate <- lapply(gen.data,function(k) tryCatch(error=function(cnd) NA,KhmaladzeTest(Y~X,data=k,taus=taus)))
    recalculate.na.rm <- Filter(Negate(anyNA), recalculate)
    na.rate <- 1-length(recalculate.na.rm)/length(recalculate)
    # Extract the test statistic
    Tn.g <- lapply(recalculate.na.rm, function(t) t$Tn)
    # Calculate p-value
    pvalue <- mean(c(1,(Tn.g>=Tn.obs)),na.rm = TRUE)
    # Export Results
    object_results$pvalue <- pvalue
    object_results$na.rate <- na.rate
  }
  
  # Export the results
  output.names <- c("p-value","NA rate")
  names(object_results) <- output.names
  return(object_results) 
}